@@ -222,7 +222,7 @@ class SessionTest(helper.CPWebCase):
             return [
                 x
                 for x in os.listdir(localDir)
-                if x.startswith('session-')
+                if x.startswith('session-') and not x.endswith('.lock')
             ]
         assert f() == []
 
@@ -236,7 +236,6 @@ class SessionTest(helper.CPWebCase):
         self.getPage('/set_session_cls/cherrypy.lib.sessions.RamSession')
         self._test_Concurrency()
 
-    @pytest.mark.xfail(reason='#1306')
     def test_2_File_Concurrency(self):
         self.getPage('/set_session_cls/cherrypy.lib.sessions.FileSession')
         pytest.skip('incosistent results (fails intermittently)')
